Tantek Çelik

1. ran #RnRSF 5k fun run non-stop. feeling ready. signed up for my first 2 half marathons: #RnRSF, and Kaiser in 22 days.

2. #RnRSF half marathon course announcement party & 5k run Sat. 9am: fb.com/events/744916795537796 Who's in? cc: @Nov_Project_SF

3. First Homebrew Website Club meetup this year is in one week 2014-015 18:30 both @MozSF @EsriPDX indiewebcamp.com/events/2014-01-15-homebrew-website-club

4. skipped my run yesterday, feeling it today. #running is the best way I've found to clear your head, heart, maximize the rest of the day.

5. @kidhack iPod Touch 5 has good chip speed, front/back cams, mic, motion(eg Nike+). Crossed a threshold. Touch ID? Meh.

6. 2014: left phone at home every day. iPod+wifi/mifi works. delete x-5278 #. #iamnotanumber #nophone #future Exception: I may start bringing my #FirefoxOS test phone with me for dogfooding, but I'm still not going to share or use the number. How to go #nophone summary: Text Messages: * iMessage * Facebook Messenger * Google+ Hangouts * AIM * Twitter DM Audio/Video calls: * FaceTime * Skype Calling the old world (government or businesses like restaurants and doctors) * G+ Hangouts, phone icon, free outbound US phone calls, no Google Voice needed. Filling in dumb web forms that require a phone number: * +1.800.555.1212 (or pick a geo-specific area code)

7. @ericnakagawa more validators welcome! Check out: microformats.org/wiki/validators Especially: indiewebify.me/validate-h-entry #indieweb

8. Nice potluck brunch. Warm park day. Random kindness of strangers at the grocery store. Today was a good day.

9. 2013 #indieweb pieces: IndieAuth comments webmention events Bridgy; 2014 together invincible. ♫ vimeo.com/40111334

10. @snarfed_org thanks & great post. Pruning+batching is good advice. Blogged re pruning ~10y ago: tantek.com/log/2003/04.html#L20030421t1700

11. In the land of the distracted, the singularly focused person is king.

12. First Thursday = another month of classes start tonight @920Special. Come #swingdance at 21:20 at 2460 Sutter & Divis.

13. 2014 work day 1: not even close to catching up on email backlog. Need to handle ever fewer emails ever more tersely.

14. @chloeweil a-ha you do have replies! Awesome! Next may I suggest reply-contexts and webmention indiewebcamp.com/reply-context

15. @chloeweil well deserved! Long way since @indiewebcamp 2011. For 2014 add @-replies to your site like this permalink to this post demonstrates. See also: indiewebcamp.com/reply

16. & #indiewebcamp veterans: Post notes on your site instead of or before Twitter. Like @chloeweil chloeweil.com/blog/hipster

17. Easy #indieweb 2014 resolution: Post more on your site than Twitter, FB, etc. Like @neilhimself journal.neilgaiman.com/2013/12/where-did-i-go-out-what-did-i-do.html

18. good 2014 start * #NPSF workout despite 13.1mi yesterday fb.com/photo.php?fbid=385734438229722 * brunches with awesome people * insightful dinner discussion

19. ...starting with a bug fix to a @Falcon storage edge case. First post of the year late POSSE. Back to normal.

20. 2014 This is the year we change things. #vulnerabilities #respect #indieweb Game on.

## Hello

My name is Tantek. I work on open web standards and the indie web. I code, design, bike, climb, run, and fight for the users.

## Recent Articles

- XFN 10th Anniversary
- Why NOT to sync iOS apps to iCloud: Ability to revert updates
- Toward A People Focused Mobile Communication Experience

## Information

Networks:
  Stanford CS Alum (B.S., M.S.)
  microformats.org (admin, founder)
  Mozilla (web standards)
Current City:
  San Francisco, CA

## Elsewhere

tantek.com is my online identity. I share, syndicate, (sometimes host) my activities elsewhere as well.

- follow @t
- Twitter notes

- Github projects
- Dribbble designs
- Instagram photos
- Flickr photos
- last.fm music
- Plancast events
- Upcoming events
- Lanyrd conferences
- Foursquare checkins
- Facebook Profile
- Google Profile
- Google Plus posts
- download vCard
- Preferred contact: aim:tantekc

## Buy my book!

A step-by-step tutorial for getting started with HTML5 today. Includes reference guide and DVD with 2.5 hours of video plus 100 page searchable full-color PDF eBook.

Buy at Amazon.com